import 'dart:async';
import 'dart:developer';
import 'dart:io' show Platform;

import 'package:geolocator/geolocator.dart';
import 'package:geolocator_android/geolocator_android.dart';
import 'package:geolocator_apple/geolocator_apple.dart';

class LocationServices {
  bool _serviceStatus = false;
  bool _hasPermission = false;
  late LocationPermission _permission;
  late Position _position;

  LocationServices() {
    _registerPlatformInstance();
  }

  void _registerPlatformInstance() {
    if (Platform.isAndroid) {
      GeolocatorAndroid.registerWith();
    } else if (Platform.isIOS) {
      GeolocatorApple.registerWith();
    }
  }

  Future<Position?> checkGps() async {
    _serviceStatus = await Geolocator.isLocationServiceEnabled();
    if (_serviceStatus) {
      _permission = await Geolocator.checkPermission();

      if (_permission == LocationPermission.denied) {
        try {
          _permission = await Geolocator.requestPermission();
        } catch (e) {
          return null;
        }
        if (_permission == LocationPermission.denied) {
          log('Location permissions are denied');
        } else if (_permission == LocationPermission.deniedForever) {
          log('Location permissions are permanently denied');
        } else {
          _hasPermission = true;
        }
      } else {
        _hasPermission = true;
      }

      if (_hasPermission) {
        return _getLocation();
      } else {
        return null;
      }
    } else {
      log('GPS Service is not enabled, turn on GPS location');
      return null;
    }
  }

  Future<Position> _getLocation() async {
    _position = await Geolocator.getCurrentPosition(desiredAccuracy: LocationAccuracy.high);

    return _position;
  }
}
